@@ -15,6 +15,7 @@ import logging
 import smtplib
 import json
 from email.mime.base import MIMEBase
+from datetime import datetime as dt, timedelta
 
 import requests
 
@@ -317,6 +318,90 @@ def clean_database():
     LOGS.logger.info("{} customers were purged from database".format(len(remainder_si)))
 
 
+def fup_customer(customer_name):
+    """Fup the customer in Aiguiller (hp only). Operation is attempted 3 times."""
+    fuped = False
+    for attempt in range(1, 3):
+        try:
+            response = requests.post(
+                CONFIG['AIGUILLIER']['url'] + "/fup?customer={}&period=hp".format(customer_name),
+                auth=(
+                    CONFIG['AIGUILLIER']['username'],
+                    CONFIG['AIGUILLIER']['password']
+                )
+            )
+            if (
+                    response.status_code == 200
+                    and response.json()['status'] == '200'
+            ):
+                fuped = True
+                break
+        except Exception as e:
+            LOGS.logger.warning(
+                "[FUP] Try {} out of 3. "
+                "Unable to add customer {} to DT database: {} "
+                .format(attempt, customer_name, str(e))
+            )
+    if fuped:
+        LOGS.logger.info(
+            "[FUP] Customer {} added to DT database"
+            .format(customer_name)
+        )
+    else:
+        LOGS.logger.error(
+            "[FUP] Unable to add customer {} to DT database"
+            .format(customer_name)
+        )
+        send_error_report(
+            "FUP customer {} from Aiguillier".format(customer_name),
+            "cf. /var/log/fup-services/fup-services.log"
+        )
+
+
+def defup_customer(customer_name):
+    """
+    Removes customer from DT database via Aiguiller.
+    Operation is attempted 3 times.
+    """
+    defuped = False
+    for attempt in range(1, 3):
+        try:
+            response = requests.delete(
+                CONFIG['AIGUILLIER']['url_v2'] + '/consommation?remettre_normal={}&periode=hp'
+                .format(customer_name),
+                auth=(
+                    CONFIG['AIGUILLIER']['username'],
+                    CONFIG['AIGUILLIER']['password']
+                )
+            )
+            if (
+                    response.status_code == 200
+                    and response.json()['status'] == '200'
+            ):
+                defuped = True
+                break
+        except Exception as e:
+            LOGS.logger.warning(
+                "[DEFUP] Try {} out of 3. "
+                "Unable to remove customer {} from DT database: {} "
+                .format(attempt, customer_name, str(e))
+            )
+    if defuped:
+        LOGS.logger.info(
+            "[DEFUP] Customer {} removed from DT database"
+            .format(customer_name)
+        )
+    else:
+        LOGS.logger.error(
+            "[DEFUP] Unable to remove customer {} from DT database"
+            .format(customer_name)
+        )
+        send_error_report(
+            "DEFUP customer {} from Aiguillier".format(customer_name),
+            "cf. /var/log/fup-services/fup-services.log"
+        )
+
+
 def record_customer(infos):
     """
     Add the given customer and its information to database
@@ -362,25 +447,72 @@ def get_product_policy(product):
 
 # =============================== CDRs =====================================
 
-def update_consommation(product, policy, customer, date, id, total):
+def update_consommation(product, policy, customer_name, fup_status, consumption):
+    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%M-%d")
     sql = (
-        "INSERT INTO fup(product, policy, customer, datetime, status, id, conso)"
-        "VALUES (?, ?, ?, ?, ?, ?, ?);"
+        "INSERT INTO fup(product, policy, customer, datetime, status, conso)"
+        "VALUES ('{product}', '{policy}', '{customer}', '{date}', '{status}','{consumption}');"
+    ).format(
+        product=product,
+        policy=policy,
+        customer=customer_name,
+        date=yesterday,
+        status=fup_status,
+        consumption=consumption
     )
+    try:
+        with records.Database(si_database_url()) as db:
+            db.query(sql)
+        LOGS.logger.info("Customer {} consumption history updated.".format(customer_name))
+    except Exception as e:
+        operation = (
+            "update customer {} consumption history"
+            .format(customer_name)
+        )
+        LOGS.logger.error("Unable to {}".format(operation))
+        send_error_report(
+            operation=operation,
+            error=str(e)
+        )
 
 
-def get_consommation_sum():
+def get_consommation_sum(customer):
+    """
+    Fetches the last 30days consumptions of a customer
+    """
+    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%M-%d")
     sql = (
         "SELECT SUM(octets_in+octets_out)"
         "FROM cdr"
         "WHERE customer ilike '%{customer}%'"
         "AND datetime >= '{date}'::date"  # YYYY-MM-DD
         "AND source='internet'"
-        "AND (extract('ISODOW' FROM datetime) between {start_date} AND {end_date})"  # dynamic based on policy
+        "AND (extract('ISODOW' FROM datetime) between 1 AND 5"
         "AND extract(HOUR FROM datetime) < 19"
         "AND extract(HOUR FROM datetime) > 8"
         "GROUP BY customer;"
-    )
+    ).format(customer=customer, date=yesterday)
+    try:
+        with records.Database(si_database_url()) as db:
+            rows = db.query(sql)
+            total = rows.as_dict()
+            if total:
+                total = total[0]
+            else:
+                total = 0
+            LOGS.logger.info(
+                "Customer {} 30days total consumption: {}"
+                .format(customer, total)
+            )
+            return total
+    except Exception as e:
+        operation = "fetch customer {} total consumption for the last 30days".format(customer)
+        LOGS.logger.error("Unable to {}".format(operation))
+        send_error_report(
+            operation=operation,
+            error=str(e)
+        )
+        return 0
 
 
 def apply_product_policies(for_real, customer):
@@ -401,6 +533,7 @@ def update_customer_cdr(last_date, customer):
         last_date=last_date
         )
 
+# ============================== utils =======================================
 
 def send_error_report(operation, error):
     """
